dafweekly

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: GPL-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Hebcal's dafweekly package calculates the Daf-a-Week schedule, a slower regimen of learning the Babylonian Talmud in which the same page (daf) is studied for an entire week. One full cycle takes about 52 years.

Index

Constants

This section is empty.

Variables

var DafWeeklyStart = greg.ToRD(2005, time.March, 6)

DafWeeklyStart is the R.D. number of the start of the Daf-a-Week cycle, Sunday 6 March 2005 (25 Adar I 5765).

Functions

func New

func New(hd hdate.HDate) (dafyomi.Daf, bool)

New calculates the Daf-a-Week page for the given date. The same daf is returned for every day of a given week.

The second return value is false when the date is before the cycle began (6 March 2005).

func NewDafWeeklyEvent

func NewDafWeeklyEvent(hd hdate.HDate, daf dafyomi.Daf) event.CalEvent

NewDafWeeklyEvent returns a calendar event for the Daf-a-Week page on the given date.

Types

This section is empty.

Jump to