dafyomi

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: GPL-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Hebcal's dafyomi package calculates the Daf Yomi, a daily regimen of learning the Babylonian Talmud.

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewDafYomiEvent

func NewDafYomiEvent(hd hdate.HDate, daf Daf) event.CalEvent

NewDafYomiEvent returns a calendar event for the Daf Yomi on the given date.

Types

type Daf

type Daf struct {
	Name  string // Tractate name (e.g. Berachot)
	Blatt int    // Page number
}

Daf represents a page of Talmud, such as Pesachim 103

func New

func New(hd hdate.HDate) (Daf, error)

New calculates the Daf Yomi for given date.

Returns an error if the date is before Daf Yomi cycle began (Hebrew year 5684, 11 September 1923).

Example
package main

import (
	"fmt"
	"time"

	"github.com/hebcal/hdate"
	"github.com/hebcal/learning/dafyomi"
)

func main() {
	hd := hdate.FromGregorian(1995, time.December, 17)
	daf, _ := dafyomi.New(hd)
	fmt.Println(daf)
}
Output:
Avodah Zarah 68

func (Daf) String

func (daf Daf) String() string

Returns a string representation of the Daf Yomi.

Jump to