nachyomi

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: GPL-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Hebcal's nachyomi package calculates the Nach Yomi, a daily regimen of learning the books of Nevi'im (Prophets) and Ketuvim (Writings).

Index

Examples

Constants

This section is empty.

Variables

var NachYomiStart = greg.ToRD(2007, time.November, 1)

NachYomiStart is the R.D. number of the start of the Nach Yomi cycle, corresponding to 1 November 2007.

Functions

func NewNachYomiEvent

func NewNachYomiEvent(hd hdate.HDate, chapter dafyomi.Daf) event.CalEvent

NewNachYomiEvent returns a calendar event for the Nach Yomi (a chapter of Nevi'im or Ketuvim) on the given date.

Types

type NachYomiIndex

type NachYomiIndex []dafyomi.Daf

NachYomiIndex is an index by day number of the entire Nach Yomi cycle.

func MakeIndex

func MakeIndex() NachYomiIndex

MakeIndex initializes the index for Mishna Yomi.

func (NachYomiIndex) Lookup

func (idx NachYomiIndex) Lookup(hd hdate.HDate) (dafyomi.Daf, error)

NachYomiIndex.Lookup calculates the Nach Yomi for given date.

Returns an error if the date is before Nach Yomi cycle began (20 May 1947).

Example
package main

import (
	"fmt"
	"time"

	"github.com/hebcal/hdate"
	"github.com/hebcal/learning/nachyomi"
)

func main() {
	idx := nachyomi.MakeIndex()
	chapter, _ := idx.Lookup(hdate.FromGregorian(2022, time.August, 1))
	fmt.Println(chapter)
}
Output:
Isaiah 47

Jump to