yerushalmi

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: GPL-2.0 Imports: 10 Imported by: 0

Documentation

Overview

Hebcal's yerushalmi package calculates the Yerushalmi Yomi, a daily regimen of learning the Jerusalem Talmud.

https://en.wikipedia.org/wiki/Jerusalem_Talmud

Index

Examples

Constants

This section is empty.

Variables

var SchottensteinStartRD = greg.ToRD(2022, time.November, 14)

SchottensteinStartRD is the R.D. date of the first cycle of Yerushalmi Yomi using the Schottenstein Edition page numbering.

var VilnaStartRD = greg.ToRD(1980, time.February, 2)

VilnaStartRD is the R.D. date of the first cycle of Yerushalmi Yomi, using the Vilna Edition page numbering.

Functions

func New

func New(hd hdate.HDate, edition Edition) dafyomi.Daf

New calculates the Daf Yomi Yerushalmi for given date.

Returns an empty Daf for Yom Kippur and Tisha B'Av.

Panics if the date is before Daf Yomi Yerushalmi cycle began (2 February 1980).

Example
package main

import (
	"fmt"
	"time"

	"github.com/hebcal/hdate"
	"github.com/hebcal/learning/yerushalmi"
)

func main() {
	hd := hdate.FromGregorian(1995, time.December, 17)
	daf := yerushalmi.New(hd, yerushalmi.Vilna)
	fmt.Println(daf)
}
Output:
Nedarim 33

func NewYerushalmiYomiEvent

func NewYerushalmiYomiEvent(hd hdate.HDate, daf dafyomi.Daf) event.CalEvent

NewYerushalmiYomiEvent returns a calendar event for the Yerushalmi Yomi (Jerusalem Talmud) on the given date.

Types

type Edition

type Edition int

Using the Vilna edition, the Yerushalmi Daf Yomi program takes ~4.25 years or 51 months. Unlike the Daf Yomi Bavli cycle, this Yerushalmi cycle skips both Yom Kippur and Tisha B'Av. The page numbers are according to the Vilna Edition which is used since 1900.

The Schottenstein edition uses different page numbers and takes ~6 years to complete.

const (
	Vilna Edition = 1 + iota
	Schottenstein
)

Jump to