Documentation
¶
Overview ¶
Hebcal's nachyomi package calculates the Nach Yomi, a daily regimen of learning the books of Nevi'im (Prophets) and Ketuvim (Writings).
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
var NachYomiStart = greg.ToRD(2007, time.November, 1)
NachYomiStart is the R.D. number of the start of the Nach Yomi cycle, corresponding to 1 November 2007.
Functions ¶
Types ¶
type NachYomiIndex ¶
NachYomiIndex is an index by day number of the entire Nach Yomi cycle.
func (NachYomiIndex) Lookup ¶
NachYomiIndex.Lookup calculates the Nach Yomi for given date.
Returns an error if the date is before Nach Yomi cycle began (20 May 1947).
Example ¶
package main
import (
"fmt"
"time"
"github.com/hebcal/hdate"
"github.com/hebcal/learning/nachyomi"
)
func main() {
idx := nachyomi.MakeIndex()
chapter, _ := idx.Lookup(hdate.FromGregorian(2022, time.August, 1))
fmt.Println(chapter)
}
Output: Isaiah 47
Click to show internal directories.
Click to hide internal directories.