Documentation
¶
Overview ¶
Hebcal's psalms package calculates the Daily Psalms (Tehillim) reading in the traditional 30-day cycle, indexed by Hebrew day of the month so that the entire book of Psalms is completed each Hebrew month.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Reading ¶
Reading is one day's slice of the 30-day Psalms cycle. Begin and End are normally chapter numbers (e.g. "10", "17"), but Psalm 119 — the longest chapter, studied over two days — uses verse-prefixed strings ("119:1"/"119:96" and "119:97"/"119:176").
Click to show internal directories.
Click to hide internal directories.