Documentation
¶
Overview ¶
Hebcal's yerushalmi package calculates the Yerushalmi Yomi, a daily regimen of learning the Jerusalem Talmud.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
var SchottensteinStartRD = greg.ToRD(2022, time.November, 14)
SchottensteinStartRD is the R.D. date of the first cycle of Yerushalmi Yomi using the Schottenstein Edition page numbering.
var VilnaStartRD = greg.ToRD(1980, time.February, 2)
VilnaStartRD is the R.D. date of the first cycle of Yerushalmi Yomi, using the Vilna Edition page numbering.
Functions ¶
func New ¶
New calculates the Daf Yomi Yerushalmi for given date.
Returns an empty Daf for Yom Kippur and Tisha B'Av.
Panics if the date is before Daf Yomi Yerushalmi cycle began (2 February 1980).
Example ¶
package main
import (
"fmt"
"time"
"github.com/hebcal/hdate"
"github.com/hebcal/learning/yerushalmi"
)
func main() {
hd := hdate.FromGregorian(1995, time.December, 17)
daf := yerushalmi.New(hd, yerushalmi.Vilna)
fmt.Println(daf)
}
Output: Nedarim 33
Types ¶
type Edition ¶
type Edition int
Using the Vilna edition, the Yerushalmi Daf Yomi program takes ~4.25 years or 51 months. Unlike the Daf Yomi Bavli cycle, this Yerushalmi cycle skips both Yom Kippur and Tisha B'Av. The page numbers are according to the Vilna Edition which is used since 1900.
The Schottenstein edition uses different page numbers and takes ~6 years to complete.